﻿using System.ComponentModel.DataAnnotations;

namespace KellermanSoftware.EncryptionCoreDemo.Models
{
    public enum EncryptionType
    {
        /// <summary>
        /// DES: http://en.wikipedia.org/wiki/Data_Encryption_Standard
        /// </summary>
        DES,
        /// <summary>
        /// RC2:  http://en.wikipedia.org/wiki/RC2
        /// </summary>
        RC2,
        /// <summary>
        /// AES: http://en.wikipedia.org/wiki/Rijndael
        /// </summary>
        Rijndael,
        /// <summary>
        /// Triple DES: http://en.wikipedia.org/wiki/Triple_DES
        /// </summary>
        TripleDES,
        /// <summary>
        /// Blowfish:  http://en.wikipedia.org/wiki/Blowfish_%28cipher%29
        /// </summary>
        Blowfish,
        /// <summary>
        /// Twofish: http://en.wikipedia.org/wiki/Twofish
        /// </summary>
        Twofish,
        /// <summary>
        /// Format Preserving Encryption from Kellerman Software
        /// </summary>
        FPEKELL1,
        /// <summary>
        /// RC4 Encryption:  https://en.wikipedia.org/wiki/RC4
        /// </summary>
        RC4,
        /// <summary>
        /// ChaCha20 Encryption:  https://en.wikipedia.org/wiki/Salsa20
        /// </summary>
        ChaCha20,
        /// <summary>
        /// Idea Encryption: https://en.wikipedia.org/wiki/International_Data_Encryption_Algorithm
        /// </summary>
        Idea,
        /// <summary>
        /// XTEA Encryption: https://en.wikipedia.org/wiki/XTEA
        /// </summary>
        XTEA,
        /// <summary>
        /// SHA1:  https://en.wikipedia.org/wiki/SHA-1
        /// </summary>
        SHA1,
        /// <summary>
        /// SHA256:  https://en.wikipedia.org/wiki/SHA-2
        /// </summary>
        SHA256,
        /// <summary>
        /// SHA384:  https://en.wikipedia.org/wiki/SHA-2
        /// </summary>
        SHA384,
        /// <summary>
        /// SHA512:  https://en.wikipedia.org/wiki/SHA-2
        /// </summary>
        SHA512,
        /// <summary>
        /// MD2:  https://en.wikipedia.org/wiki/MD2_(hash_function)
        /// </summary>
        MD2,
        /// <summary>
        /// MD4: https://en.wikipedia.org/wiki/MD4
        /// </summary>
        MD4,
        /// <summary>
        /// MD5:  https://en.wikipedia.org/wiki/MD5
        /// </summary>
        MD5,
        /// <summary>
        /// HAVAL: https://en.wikipedia.org/wiki/HAVAL
        /// </summary>
        HAVAL,
        /// <summary>
        /// Ripemd160: https://en.wikipedia.org/wiki/RIPEMD
        /// </summary>
        Ripemd160,
        /// <summary>
        /// Ripemd320: https://en.wikipedia.org/wiki/RIPEMD
        /// </summary>
        Ripemd320,
        /// <summary>
        /// GOST: https://en.wikipedia.org/wiki/GOST_(hash_function)
        /// </summary>
        GostHash,
        /// <summary>
        /// Whirlpool: https://en.wikipedia.org/wiki/Whirlpool_(hash_function)
        /// </summary>
        Whirlpool,
        /// <summary>
        /// Tiger:  https://en.wikipedia.org/wiki/Tiger_(hash_function)
        /// </summary>
        Tiger,
        /// <summary>
        /// FCS16:  https://en.wikipedia.org/wiki/Frame_check_sequence
        /// </summary>
        FCS16,
        /// <summary>
        /// FCS32: https://en.wikipedia.org/wiki/Frame_check_sequence
        /// </summary>
        FCS32,
        /// <summary>
        /// HMACSHA256: https://en.wikipedia.org/wiki/HMAC
        /// </summary>
        HMACSHA256,
        /// <summary>
        /// HMACSHA25696:  https://en.wikipedia.org/wiki/HMAC
        /// </summary>
        HMACSHA25696,
        /// <summary>
        /// HMACSHA384: https://en.wikipedia.org/wiki/HMAC
        /// </summary>
        HMACSHA384,
        /// <summary>
        /// HMACSHA512: https://en.wikipedia.org/wiki/HMAC
        /// </summary>
        HMACSHA512,
        /// <summary>
        /// HMACSHA51296:  https://en.wikipedia.org/wiki/HMAC
        /// </summary>
        HMACSHA51296,
        /// <summary>
        /// HMACSHA1:  https://en.wikipedia.org/wiki/HMAC
        /// </summary>
        HMACSHA1,
        /// <summary>
        /// HMACSHA196:  https://en.wikipedia.org/wiki/HMAC
        /// </summary>
        HMACSHA196,
        /// <summary>
        /// HMACMD596:  https://en.wikipedia.org/wiki/HMAC
        /// </summary>
        HMACMD596,
        GHash,
        /// <summary>
        /// https://en.wikipedia.org/wiki/BSD_checksum
        /// </summary>
        SumBSD,
        /// <summary>
        /// Grindahl256: https://ehash.iaik.tugraz.at/wiki/Grindahl-256
        /// </summary>
        Grindahl256,
        /// <summary>
        /// Grindahl512: https://ehash.iaik.tugraz.at/wiki/Grindahl-256
        /// </summary>
        Grindahl512,
        /// <summary>
        /// RadioGatun32: https://en.wikipedia.org/wiki/RadioGat%C3%BAn
        /// </summary>
        RadioGatun32,
        /// <summary>
        /// RadioGatun64: https://en.wikipedia.org/wiki/RadioGat%C3%BAn
        /// </summary>
        RadioGatun64,
        /// <summary>
        /// Skein224: https://en.wikipedia.org/wiki/Skein_(hash_function)
        /// </summary>
        Skein224,
        /// <summary>
        /// Skein256: https://en.wikipedia.org/wiki/Skein_(hash_function)
        /// </summary>
        Skein256,
        /// <summary>
        /// Skein384: https://en.wikipedia.org/wiki/Skein_(hash_function)
        /// </summary>
        Skein384,
        /// <summary>
        /// Skein512: https://en.wikipedia.org/wiki/Skein_(hash_function)
        /// </summary>
        Skein512,
        /// <summary>
        /// Blake224: https://en.wikipedia.org/wiki/BLAKE_(hash_function)
        /// </summary>
        Blake224,
        /// <summary>
        /// Blake256: https://en.wikipedia.org/wiki/BLAKE_(hash_function)
        /// </summary>
        Blake256,
        /// <summary>
        /// Blake384: https://en.wikipedia.org/wiki/BLAKE_(hash_function)
        /// </summary>
        Blake384,
        /// <summary>
        /// Blake512: https://en.wikipedia.org/wiki/BLAKE_(hash_function)
        /// </summary>
        Blake512,
        /// <summary>
        /// Keccak224: https://en.wikipedia.org/wiki/SHA-3
        /// </summary>
        Keccak224,
        /// <summary>
        /// Keccak256: https://en.wikipedia.org/wiki/SHA-3
        /// </summary>
        Keccak256,
        /// <summary>
        /// Keccak384: https://en.wikipedia.org/wiki/SHA-3
        /// </summary>
        Keccak384,
        /// <summary>
        /// Keccak512: https://en.wikipedia.org/wiki/SHA-3
        /// </summary>
        Keccak512
    }

    public class EncryptionViewModel
    {
        [Display(Name = "User Name")]
        public string UserName { get; set; }

        [Display(Name = "License")]
        public string LicenseKey { get; set; }

        [Required]
        [Display(Name = "Type")]
        public EncryptionType EncryptType { get; set; }

        [Required]
        public string IV { get; set; }

        [Required]
        public string Salt { get; set; }

        [Required]
        public string Key { get; set; }

        [Required]
        [Display(Name = "String To Encrypt")]
        public string Message { get; set; }

        [Display(Name = "Encrypted String")]
        public string EncryptedString { get; set; }

        [Display(Name = "Decrypted String")]
        public string DecryptedString { get; set; }
    }
}
